@@ -49,7 +49,7 @@ define('PEAR_DOWNLOADER_PACKAGE_PHPVERSION', -1004);
  * @author     Greg Beaver <cellog@php.net>
  * @copyright  1997-2009 The Authors
  * @license    http://opensource.org/licenses/bsd-license.php New BSD License
- * @version    Release: 1.10.1
+ * @version    Release: 1.10.7
  * @link       http://pear.php.net/package/PEAR
  * @since      Class available since Release 1.4.0a1
  */
@@ -1507,7 +1507,7 @@ class PEAR_Downloader_Package
     function _fromFile(&$param)
     {
         $saveparam = $param;
-        if (is_string($param)) {
+        if (is_string($param) && substr($param, 0, 10) !== 'channel://') {
             if (!@file_exists($param)) {
                 $test = explode('#', $param);
                 $group = array_pop($test);
